summary method for class html2excel.
Arguments
- object
An object inheriting from class
"html2excel"returned fromhtml2excel.- ...
Further arguments to be passed to
print.default.- x
An object returned by
summary.html2excel.
Details
The default print method for a list of tibbles prints the
dimensions of the tibbles and up to 10 rows and 6 columns of each tibble.
summary.html2excel prints a shorter summary that contains only the
dimensions of the tibbles. These print and/or summary methods may be
helpful in deciding which sheets are required for which excel file, that
is, how to set the argument sheets to html2excel.
Examples
See html2excel.